==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/PrincipalRateLimitEntity.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.PrincipalType;
import java.time.OffsetDateTime;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
*
*/
@ApiModel(description = "")
@JsonPropertyOrder({ PrincipalRateLimitEntity.JSON_PROPERTY_CREATED_BY,
        PrincipalRateLimitEntity.JSON_PROPERTY_CREATED_DATE,
        PrincipalRateLimitEntity.JSON_PROPERTY_DEFAULT_CONCURRENCY_PERCENTAGE,
        PrincipalRateLimitEntity.JSON_PROPERTY_DEFAULT_PERCENTAGE, PrincipalRateLimitEntity.JSON_PROPERTY_ID,
        PrincipalRateLimitEntity.JSON_PROPERTY_LAST_UPDATE, PrincipalRateLimitEntity.JSON_PROPERTY_LAST_UPDATED_BY,
        PrincipalRateLimitEntity.JSON_PROPERTY_ORG_ID, PrincipalRateLimitEntity.JSON_PROPERTY_PRINCIPAL_ID,
        PrincipalRateLimitEntity.JSON_PROPERTY_PRINCIPAL_TYPE })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class PrincipalRateLimitEntity implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_CREATED_BY = "createdBy";
    private String createdBy;

    public static final String JSON_PROPERTY_CREATED_DATE = "createdDate";
    private OffsetDateTime createdDate;

    public static final String JSON_PROPERTY_DEFAULT_CONCURRENCY_PERCENTAGE = "defaultConcurrencyPercentage";
    private Integer defaultConcurrencyPercentage;

    public static final String JSON_PROPERTY_DEFAULT_PERCENTAGE = "defaultPercentage";
    private Integer defaultPercentage;

    public static final String JSON_PROPERTY_ID = "id";
    private String id;

    public static final String JSON_PROPERTY_LAST_UPDATE = "lastUpdate";
    private OffsetDateTime lastUpdate;

    public static final String JSON_PROPERTY_LAST_UPDATED_BY = "lastUpdatedBy";
    private String lastUpdatedBy;

    public static final String JSON_PROPERTY_ORG_ID = "orgId";
    private String orgId;

    public static final String JSON_PROPERTY_PRINCIPAL_ID = "principalId";
    private String principalId;

    public static final String JSON_PROPERTY_PRINCIPAL_TYPE = "principalType";
    private PrincipalType principalType;

    public PrincipalRateLimitEntity() {
    }

    /*
     * @JsonCreator public PrincipalRateLimitEntity(
     *
     * @JsonProperty(JSON_PROPERTY_CREATED_BY) String createdBy,
     *
     * @JsonProperty(JSON_PROPERTY_CREATED_DATE) OffsetDateTime createdDate,
     *
     * @JsonProperty(JSON_PROPERTY_DEFAULT_CONCURRENCY_PERCENTAGE) Integer defaultConcurrencyPercentage,
     *
     * @JsonProperty(JSON_PROPERTY_DEFAULT_PERCENTAGE) Integer defaultPercentage,
     *
     * @JsonProperty(JSON_PROPERTY_ID) String id,
     *
     * @JsonProperty(JSON_PROPERTY_LAST_UPDATE) OffsetDateTime lastUpdate,
     *
     * @JsonProperty(JSON_PROPERTY_LAST_UPDATED_BY) String lastUpdatedBy,
     *
     * @JsonProperty(JSON_PROPERTY_ORG_ID) String orgId ) { this(); this.createdBy = createdBy; this.createdDate =
     * createdDate; this.defaultConcurrencyPercentage = defaultConcurrencyPercentage; this.defaultPercentage =
     * defaultPercentage; this.id = id; this.lastUpdate = lastUpdate; this.lastUpdatedBy = lastUpdatedBy; this.orgId =
     * orgId; }
     */

    /**
     * Get createdBy
     *
     * @return createdBy
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CREATED_BY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getCreatedBy() {
        return createdBy;
    }

    /**
     * Get createdDate
     *
     * @return createdDate
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CREATED_DATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public OffsetDateTime getCreatedDate() {
        return createdDate;
    }

    /**
     * Get defaultConcurrencyPercentage
     *
     * @return defaultConcurrencyPercentage
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_DEFAULT_CONCURRENCY_PERCENTAGE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Integer getDefaultConcurrencyPercentage() {
        return defaultConcurrencyPercentage;
    }

    /**
     * Get defaultPercentage
     *
     * @return defaultPercentage
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_DEFAULT_PERCENTAGE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Integer getDefaultPercentage() {
        return defaultPercentage;
    }

    /**
     * Get id
     *
     * @return id
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getId() {
        return id;
    }

    /**
     * Get lastUpdate
     *
     * @return lastUpdate
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_LAST_UPDATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public OffsetDateTime getLastUpdate() {
        return lastUpdate;
    }

    /**
     * Get lastUpdatedBy
     *
     * @return lastUpdatedBy
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_LAST_UPDATED_BY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getLastUpdatedBy() {
        return lastUpdatedBy;
    }

    /**
     * Get orgId
     *
     * @return orgId
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ORG_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getOrgId() {
        return orgId;
    }

    public PrincipalRateLimitEntity principalId(String principalId) {

        this.principalId = principalId;
        return this;
    }

    /**
     * Get principalId
     *
     * @return principalId
     **/
    @javax.annotation.Nonnull
    @ApiModelProperty(required = true, value = "")
    @JsonProperty(JSON_PROPERTY_PRINCIPAL_ID)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)

    public String getPrincipalId() {
        return principalId;
    }

    @JsonProperty(JSON_PROPERTY_PRINCIPAL_ID)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)
    public void setPrincipalId(String principalId) {
        this.principalId = principalId;
    }

    public PrincipalRateLimitEntity principalType(PrincipalType principalType) {

        this.principalType = principalType;
        return this;
    }

    /**
     * Get principalType
     *
     * @return principalType
     **/
    @javax.annotation.Nonnull
    @ApiModelProperty(required = true, value = "")
    @JsonProperty(JSON_PROPERTY_PRINCIPAL_TYPE)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)

    public PrincipalType getPrincipalType() {
        return principalType;
    }

    @JsonProperty(JSON_PROPERTY_PRINCIPAL_TYPE)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)
    public void setPrincipalType(PrincipalType principalType) {
        this.principalType = principalType;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        PrincipalRateLimitEntity principalRateLimitEntity = (PrincipalRateLimitEntity) o;
        return Objects.equals(this.createdBy, principalRateLimitEntity.createdBy)
                && Objects.equals(this.createdDate, principalRateLimitEntity.createdDate)
                && Objects.equals(this.defaultConcurrencyPercentage,
                        principalRateLimitEntity.defaultConcurrencyPercentage)
                && Objects.equals(this.defaultPercentage, principalRateLimitEntity.defaultPercentage)
                && Objects.equals(this.id, principalRateLimitEntity.id)
                && Objects.equals(this.lastUpdate, principalRateLimitEntity.lastUpdate)
                && Objects.equals(this.lastUpdatedBy, principalRateLimitEntity.lastUpdatedBy)
                && Objects.equals(this.orgId, principalRateLimitEntity.orgId)
                && Objects.equals(this.principalId, principalRateLimitEntity.principalId)
                && Objects.equals(this.principalType, principalRateLimitEntity.principalType);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(createdBy, createdDate, defaultConcurrencyPercentage, defaultPercentage, id, lastUpdate,
                lastUpdatedBy, orgId, principalId, principalType);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PrincipalRateLimitEntity {\n");
        sb.append("    createdBy: ").append(toIndentedString(createdBy)).append("\n");
        sb.append("    createdDate: ").append(toIndentedString(createdDate)).append("\n");
        sb.append("    defaultConcurrencyPercentage: ").append(toIndentedString(defaultConcurrencyPercentage))
                .append("\n");
        sb.append("    defaultPercentage: ").append(toIndentedString(defaultPercentage)).append("\n");
        sb.append("    id: ").append(toIndentedString(id)).append("\n");
        sb.append("    lastUpdate: ").append(toIndentedString(lastUpdate)).append("\n");
        sb.append("    lastUpdatedBy: ").append(toIndentedString(lastUpdatedBy)).append("\n");
        sb.append("    orgId: ").append(toIndentedString(orgId)).append("\n");
        sb.append("    principalId: ").append(toIndentedString(principalId)).append("\n");
        sb.append("    principalType: ").append(toIndentedString(principalType)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/PrincipalRateLimitEntity.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.PrincipalType;
import java.time.OffsetDateTime;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
*
*/
@ApiModel(description = "")
@JsonPropertyOrder({ PrincipalRateLimitEntity.JSON_PROPERTY_CREATED_BY,
        PrincipalRateLimitEntity.JSON_PROPERTY_CREATED_DATE,
        PrincipalRateLimitEntity.JSON_PROPERTY_DEFAULT_CONCURRENCY_PERCENTAGE,
        PrincipalRateLimitEntity.JSON_PROPERTY_DEFAULT_PERCENTAGE, PrincipalRateLimitEntity.JSON_PROPERTY_ID,
        PrincipalRateLimitEntity.JSON_PROPERTY_LAST_UPDATE, PrincipalRateLimitEntity.JSON_PROPERTY_LAST_UPDATED_BY,
        PrincipalRateLimitEntity.JSON_PROPERTY_ORG_ID, PrincipalRateLimitEntity.JSON_PROPERTY_PRINCIPAL_ID,
        PrincipalRateLimitEntity.JSON_PROPERTY_PRINCIPAL_TYPE })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class PrincipalRateLimitEntity implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_CREATED_BY = "createdBy";
    private String createdBy;

    public static final String JSON_PROPERTY_CREATED_DATE = "createdDate";
    private OffsetDateTime createdDate;

    public static final String JSON_PROPERTY_DEFAULT_CONCURRENCY_PERCENTAGE = "defaultConcurrencyPercentage";
    private Integer defaultConcurrencyPercentage;

    public static final String JSON_PROPERTY_DEFAULT_PERCENTAGE = "defaultPercentage";
    private Integer defaultPercentage;

    public static final String JSON_PROPERTY_ID = "id";
    private String id;

    public static final String JSON_PROPERTY_LAST_UPDATE = "lastUpdate";
    private OffsetDateTime lastUpdate;

    public static final String JSON_PROPERTY_LAST_UPDATED_BY = "lastUpdatedBy";
    private String lastUpdatedBy;

    public static final String JSON_PROPERTY_ORG_ID = "orgId";
    private String orgId;

    public static final String JSON_PROPERTY_PRINCIPAL_ID = "principalId";
    private String principalId;

    public static final String JSON_PROPERTY_PRINCIPAL_TYPE = "principalType";
    private PrincipalType principalType;

    public PrincipalRateLimitEntity() {
    }

    /*
     * @JsonCreator public PrincipalRateLimitEntity(
     *
     * @JsonProperty(JSON_PROPERTY_CREATED_BY) String createdBy,
     *
     * @JsonProperty(JSON_PROPERTY_CREATED_DATE) OffsetDateTime createdDate,
     *
     * @JsonProperty(JSON_PROPERTY_DEFAULT_CONCURRENCY_PERCENTAGE) Integer defaultConcurrencyPercentage,
     *
     * @JsonProperty(JSON_PROPERTY_DEFAULT_PERCENTAGE) Integer defaultPercentage,
     *
     * @JsonProperty(JSON_PROPERTY_ID) String id,
     *
     * @JsonProperty(JSON_PROPERTY_LAST_UPDATE) OffsetDateTime lastUpdate,
     *
     * @JsonProperty(JSON_PROPERTY_LAST_UPDATED_BY) String lastUpdatedBy,
     *
     * @JsonProperty(JSON_PROPERTY_ORG_ID) String orgId ) { this(); this.createdBy = createdBy; this.createdDate =
     * createdDate; this.defaultConcurrencyPercentage = defaultConcurrencyPercentage; this.defaultPercentage =
     * defaultPercentage; this.id = id; this.lastUpdate = lastUpdate; this.lastUpdatedBy = lastUpdatedBy; this.orgId =
     * orgId; }
     */

    /**
     * Get createdBy
     *
     * @return createdBy
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CREATED_BY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getCreatedBy() {
        return createdBy;
    }

    /**
     * Get createdDate
     *
     * @return createdDate
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CREATED_DATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public OffsetDateTime getCreatedDate() {
        return createdDate;
    }

    /**
     * Get defaultConcurrencyPercentage
     *
     * @return defaultConcurrencyPercentage
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_DEFAULT_CONCURRENCY_PERCENTAGE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Integer getDefaultConcurrencyPercentage() {
        return defaultConcurrencyPercentage;
    }

    /**
     * Get defaultPercentage
     *
     * @return defaultPercentage
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_DEFAULT_PERCENTAGE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Integer getDefaultPercentage() {
        return defaultPercentage;
    }

    /**
     * Get id
     *
     * @return id
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getId() {
        return id;
    }

    /**
     * Get lastUpdate
     *
     * @return lastUpdate
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_LAST_UPDATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public OffsetDateTime getLastUpdate() {
        return lastUpdate;
    }

    /**
     * Get lastUpdatedBy
     *
     * @return lastUpdatedBy
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_LAST_UPDATED_BY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getLastUpdatedBy() {
        return lastUpdatedBy;
    }

    /**
     * Get orgId
     *
     * @return orgId
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ORG_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getOrgId() {
        return orgId;
    }

    public PrincipalRateLimitEntity principalId(String principalId) {

        this.principalId = principalId;
        return this;
    }

    /**
     * Get principalId
     *
     * @return principalId
     **/
    @javax.annotation.Nonnull
    @ApiModelProperty(required = true, value = "")
    @JsonProperty(JSON_PROPERTY_PRINCIPAL_ID)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)

    public String getPrincipalId() {
        return principalId;
    }

    @JsonProperty(JSON_PROPERTY_PRINCIPAL_ID)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)
    public void setPrincipalId(String principalId) {
        this.principalId = principalId;
    }

    public PrincipalRateLimitEntity principalType(PrincipalType principalType) {

        this.principalType = principalType;
        return this;
    }

    /**
     * Get principalType
     *
     * @return principalType
     **/
    @javax.annotation.Nonnull
    @ApiModelProperty(required = true, value = "")
    @JsonProperty(JSON_PROPERTY_PRINCIPAL_TYPE)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)

    public PrincipalType getPrincipalType() {
        return principalType;
    }

    @JsonProperty(JSON_PROPERTY_PRINCIPAL_TYPE)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)
    public void setPrincipalType(PrincipalType principalType) {
        this.principalType = principalType;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        PrincipalRateLimitEntity principalRateLimitEntity = (PrincipalRateLimitEntity) o;
        return Objects.equals(this.createdBy, principalRateLimitEntity.createdBy)
                && Objects.equals(this.createdDate, principalRateLimitEntity.createdDate)
                && Objects.equals(this.defaultConcurrencyPercentage,
                        principalRateLimitEntity.defaultConcurrencyPercentage)
                && Objects.equals(this.defaultPercentage, principalRateLimitEntity.defaultPercentage)
                && Objects.equals(this.id, principalRateLimitEntity.id)
                && Objects.equals(this.lastUpdate, principalRateLimitEntity.lastUpdate)
                && Objects.equals(this.lastUpdatedBy, principalRateLimitEntity.lastUpdatedBy)
                && Objects.equals(this.orgId, principalRateLimitEntity.orgId)
                && Objects.equals(this.principalId, principalRateLimitEntity.principalId)
                && Objects.equals(this.principalType, principalRateLimitEntity.principalType);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(createdBy, createdDate, defaultConcurrencyPercentage, defaultPercentage, id, lastUpdate,
                lastUpdatedBy, orgId, principalId, principalType);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PrincipalRateLimitEntity {\n");
        sb.append("    createdBy: ").append(toIndentedString(createdBy)).append("\n");
        sb.append("    createdDate: ").append(toIndentedString(createdDate)).append("\n");
        sb.append("    defaultConcurrencyPercentage: ").append(toIndentedString(defaultConcurrencyPercentage))
                .append("\n");
        sb.append("    defaultPercentage: ").append(toIndentedString(defaultPercentage)).append("\n");
        sb.append("    id: ").append(toIndentedString(id)).append("\n");
        sb.append("    lastUpdate: ").append(toIndentedString(lastUpdate)).append("\n");
        sb.append("    lastUpdatedBy: ").append(toIndentedString(lastUpdatedBy)).append("\n");
        sb.append("    orgId: ").append(toIndentedString(orgId)).append("\n");
        sb.append("    principalId: ").append(toIndentedString(principalId)).append("\n");
        sb.append("    principalType: ").append(toIndentedString(principalType)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
